% Matlab script to run trussFEA code
% Written for MN 203 in January 2020 (G. K. Ananthasuresh)
%
close all; clear all; clc; hold off; % Housekeeping commands
% Load data and save into appropriate arrays
load node.dat
NNODE = size(node,1);
for i = 1:NNODE,
    nx(i) = node(i,2);
    ny(i) = node(i,3);
end
load elem.dat
NELEM = size(elem,1);
for i = 1:NELEM,
    ncon(i,1) = elem(i,2);
    ncon(i,2) = elem(i,3);
    A(i) = elem(i,4);
    E(i) = elem(i,5);
    lx = nx(ncon(i,2)) - nx(ncon(i,1));
    ly = ny(ncon(i,2)) - ny(ncon(i,2));
    L(i) = sqrt(lx^2+ly^2);
end
load forces.dat
F = zeros(2*NNODE,1);
for i = 1:size(forces,1),
    forceID = 2*(forces(i,2)-1) + forces(i,3);
    F(forceID) = forces(i,4);
end
load dispbc.dat
for i = 1:size(dispbc,1),
    dispID(i) = 2*(dispbc(i,2)-1) + dispbc(i,3);
end
dispID = dispID';
%
[u,Rdisp,P,Ksing,SE,SEgrad] = ...
    femtruss(A, L, E, nx, ny, ncon, NELEM, NNODE, F, dispID);
% Plotting truss and its deformation
figure(1)
clf
for i = 1:NELEM,
    eye = ncon(i,1);
    jay = ncon(i,2);
    plot([nx(eye) nx(jay)],[ny(eye) ny(jay)],'-k');
    hold on
    plot([nx(eye) nx(jay)],[ny(eye) ny(jay)],'ko');
    dx1 = u(2*eye-1);
    dx2 = u(2*jay-1);
    dy1 = u(2*eye);
    dy2 = u(2*jay);
    plot([nx(eye)+dx1 nx(jay)+dx2],[ny(eye)+dy1 ny(jay)+dy2],'-r');
    plot([nx(eye)+dx1 nx(jay)+dx2],[ny(eye)+dy1 ny(jay)+dy2],'ro');
end
axis equal




